@@ -1,3 +1,3 @@
 from scraper import instagram_profile_json
 
-print(instagram_profile_json("farandride"))
\ No newline at end of file
+print(instagram_profile_json("tomcruise"))
\ No newline at end of file
